
Input rejection
-------

**Description:**

Whenever the application detects malicious or unexpected user-input you want to make sure 
the application actual rejects the submitted user-input rather than directly process it. 


**Solution:**

Verify that the application actual rejects, sanitise or format your user-input into not 
malicious data. 

	